@@ -472,12 +472,19 @@ nsresult nsCocoaUtils::CreateNSImageFromImageContainer(imgIContainer *aImage, ui
     int scaledWidth = (int)ceilf(width * scaleFactor);
     int scaledHeight = (int)ceilf(height * scaleFactor);
 
-    nsRefPtr<gfxImageSurface> frame =
-      new gfxImageSurface(gfxIntSize(scaledWidth, scaledHeight), gfxImageFormat::ARGB32);
-    NS_ENSURE_TRUE(frame, NS_ERROR_FAILURE);
+    RefPtr<DrawTarget> drawTarget = gfxPlatform::GetPlatform()->
+      CreateOffscreenContentDrawTarget(IntSize(scaledWidth, scaledHeight),
+                                       SurfaceFormat::B8G8R8A8);
+    if (!drawTarget) {
+      NS_ERROR("Failed to create DrawTarget");
+      return NS_ERROR_FAILURE;
+    }
 
-    nsRefPtr<gfxContext> context = new gfxContext(frame);
-    NS_ENSURE_TRUE(context, NS_ERROR_FAILURE);
+    nsRefPtr<gfxContext> context = new gfxContext(drawTarget);
+    if (!context) {
+      NS_ERROR("Failed to create gfxContext");
+      return NS_ERROR_FAILURE;
+    }
 
     aImage->Draw(context, GraphicsFilter::FILTER_NEAREST, gfxMatrix(),
       gfxRect(0.0f, 0.0f, scaledWidth, scaledHeight),
@@ -485,8 +492,7 @@ nsresult nsCocoaUtils::CreateNSImageFromImageContainer(imgIContainer *aImage, ui
       nsIntSize(scaledWidth, scaledHeight),
       nullptr, aWhichFrame, imgIContainer::FLAG_SYNC_DECODE);
 
-    surface =
-      gfxPlatform::GetPlatform()->GetSourceSurfaceForSurface(nullptr, frame);
+    surface = drawTarget->Snapshot();
   } else {
     surface = aImage->GetFrame(aWhichFrame, imgIContainer::FLAG_SYNC_DECODE);
   }
